[Cmake-commits] CMake branch, master, updated. v3.9.1-753-g10a3835

Kitware Robot kwrobot at kitware.com
Thu Sep 7 11:25:31 EDT 2017


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
       via  10a3835cbd94d7c7fa6176c142c7a12449dfe160 (commit)
       via  14ea80ab0cbdd98551403b62a34540e1031dff31 (commit)
       via  67a840b3c8ab768d924d8b9fa978599f915c4528 (commit)
       via  e6159e1842650c894c642964f448b01ae6eb8a99 (commit)
       via  6dd0a593d94a386f026f9a83fc7f6c33a9356cc1 (commit)
       via  1dd2c08b199bb451b73e438d62c1b05f6ccc5bd7 (commit)
       via  3a4f82e9f2edc9cf30c45019685d26658906e48e (commit)
       via  bfe51369a7f2dd29eb08f24b877fdd01b7534e5c (commit)
       via  78f166f8730c4da4ad21ba6218803f1a6552a95a (commit)
      from  de80352d5b44fafba97baee935f35527ee427d45 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=10a3835cbd94d7c7fa6176c142c7a12449dfe160
commit 10a3835cbd94d7c7fa6176c142c7a12449dfe160
Merge: 14ea80a e6159e1
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Thu Sep 7 15:22:56 2017 +0000
Commit:     Kitware Robot <kwrobot at kitware.com>
CommitDate: Thu Sep 7 11:23:00 2017 -0400

    Merge topic 'FindBoost-limit-configs'
    
    e6159e18 FindBoost: Add option to prevent finding DEBUG/RELEASE Boost-libs
    
    Acked-by: Kitware Robot <kwrobot at kitware.com>
    Merge-request: !1216


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=14ea80ab0cbdd98551403b62a34540e1031dff31
commit 14ea80ab0cbdd98551403b62a34540e1031dff31
Merge: 67a840b 3a4f82e
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Thu Sep 7 15:22:18 2017 +0000
Commit:     Kitware Robot <kwrobot at kitware.com>
CommitDate: Thu Sep 7 11:22:26 2017 -0400

    Merge topic 'findexpat-importedtargets'
    
    3a4f82e9 Help: Add notes for topic 'FindEXPAT-importedtargets'
    bfe51369 FindEXPAT: Add unit test of target and variables
    78f166f8 FindEXPAT: Add imported target and documentation
    
    Acked-by: Kitware Robot <kwrobot at kitware.com>
    Merge-request: !1207


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=67a840b3c8ab768d924d8b9fa978599f915c4528
commit 67a840b3c8ab768d924d8b9fa978599f915c4528
Merge: de80352 6dd0a59
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Thu Sep 7 15:17:12 2017 +0000
Commit:     Kitware Robot <kwrobot at kitware.com>
CommitDate: Thu Sep 7 11:17:33 2017 -0400

    Merge topic 'irsl-vs15-future'
    
    6dd0a593 Merge branch 'backport-irsl-vs15-future' into irsl-vs15-future
    1dd2c08b InstallRequiredSystemLibraries: Add support for future VS 2017 toolchains
    
    Acked-by: Kitware Robot <kwrobot at kitware.com>
    Acked-by: Christian Pfeiffer <cpfeiffer at live.de>
    Merge-request: !1240


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e6159e1842650c894c642964f448b01ae6eb8a99
commit e6159e1842650c894c642964f448b01ae6eb8a99
Author:     Deniz Bahadir <d.bahadir at gmx.de>
AuthorDate: Thu Aug 31 06:46:36 2017 -0400
Commit:     Deniz Bahadir <dbahadir at benocs.com>
CommitDate: Wed Sep 6 17:58:45 2017 +0200

    FindBoost: Add option to prevent finding DEBUG/RELEASE Boost-libs
    
    With the use of options `Boost_USE_DEBUG_LIBS` and
    `Boost_USE_RELEASE_LIBS` it is now possible to skip searching for either
    DEBUG or RELEASE Boost libraries.
    This is useful if Boost is installed on the system in multiple
    directories but only one of them should be used which only contains e.g.
    the RELEASE libraries. Without this change the DEBUG libraries might be
    found in the other directory which might not be desired at all.

diff --git a/Modules/FindBoost.cmake b/Modules/FindBoost.cmake
index b28f2b8..7de5b5b 100644
--- a/Modules/FindBoost.cmake
+++ b/Modules/FindBoost.cmake
@@ -107,6 +107,10 @@
 # Users or projects may tell this module which variant to find by
 # setting variables::
 #
+#   Boost_USE_DEBUG_LIBS     - Set to ON or OFF to specify whether to search
+#                              and use the debug libraries.  Default is ON.
+#   Boost_USE_RELEASE_LIBS   - Set to ON or OFF to specify whether to search
+#                              and use the release libraries.  Default is ON.
 #   Boost_USE_MULTITHREADED  - Set to OFF to use the non-multithreaded
 #                              libraries ('mt' tag).  Default is ON.
 #   Boost_USE_STATIC_LIBS    - Set to ON to force the use of the static
@@ -183,9 +187,11 @@
 #   target_link_libraries(foo Boost::date_time Boost::filesystem
 #                             Boost::iostreams)
 #
-# Example to find Boost headers and some *static* libraries::
+# Example to find Boost headers and some *static* (release only) libraries::
 #
-#   set(Boost_USE_STATIC_LIBS        ON) # only find static libs
+#   set(Boost_USE_STATIC_LIBS        ON)  # only find static libs
+#   set(Boost_USE_DEBUG_LIBS         OFF) # ignore debug libs and
+#   set(Boost_USE_RELEASE_LIBS       ON)  # only find release libs
 #   set(Boost_USE_MULTITHREADED      ON)
 #   set(Boost_USE_STATIC_RUNTIME    OFF)
 #   find_package(Boost 1.36.0 COMPONENTS date_time filesystem system ...)
@@ -298,7 +304,7 @@ macro(_Boost_ADJUST_LIB_VARS basename)
     endif()
 
     # If the debug & release library ends up being the same, omit the keywords
-    if(${Boost_${basename}_LIBRARY_RELEASE} STREQUAL ${Boost_${basename}_LIBRARY_DEBUG})
+    if("${Boost_${basename}_LIBRARY_RELEASE}" STREQUAL "${Boost_${basename}_LIBRARY_DEBUG}")
       set(Boost_${basename}_LIBRARY   ${Boost_${basename}_LIBRARY_RELEASE} )
       set(Boost_${basename}_LIBRARIES ${Boost_${basename}_LIBRARY_RELEASE} )
     endif()
@@ -996,8 +1002,14 @@ if(NOT Boost_LIBRARY_DIR_DEBUG AND Boost_LIBRARY_DIR)
   set(Boost_LIBRARY_DIR_DEBUG   "${Boost_LIBRARY_DIR}")
 endif()
 
+if(NOT DEFINED Boost_USE_DEBUG_LIBS)
+  set(Boost_USE_DEBUG_LIBS TRUE)
+endif()
+if(NOT DEFINED Boost_USE_RELEASE_LIBS)
+  set(Boost_USE_RELEASE_LIBS TRUE)
+endif()
 if(NOT DEFINED Boost_USE_MULTITHREADED)
-    set(Boost_USE_MULTITHREADED TRUE)
+  set(Boost_USE_MULTITHREADED TRUE)
 endif()
 if(NOT DEFINED Boost_USE_DEBUG_RUNTIME)
   set(Boost_USE_DEBUG_RUNTIME TRUE)
@@ -1631,12 +1643,14 @@ foreach(COMPONENT ${Boost_FIND_COMPONENTS})
   # Avoid passing backslashes to _Boost_FIND_LIBRARY due to macro re-parsing.
   string(REPLACE "\\" "/" _boost_LIBRARY_SEARCH_DIRS_tmp "${_boost_LIBRARY_SEARCH_DIRS_RELEASE}")
 
-  _Boost_FIND_LIBRARY(Boost_${UPPERCOMPONENT}_LIBRARY_RELEASE RELEASE
-    NAMES ${_boost_RELEASE_NAMES}
-    HINTS ${_boost_LIBRARY_SEARCH_DIRS_tmp}
-    NAMES_PER_DIR
-    DOC "${_boost_docstring_release}"
-    )
+  if(Boost_USE_RELEASE_LIBS)
+    _Boost_FIND_LIBRARY(Boost_${UPPERCOMPONENT}_LIBRARY_RELEASE RELEASE
+      NAMES ${_boost_RELEASE_NAMES}
+      HINTS ${_boost_LIBRARY_SEARCH_DIRS_tmp}
+      NAMES_PER_DIR
+      DOC "${_boost_docstring_release}"
+      )
+  endif()
 
   #
   # Find DEBUG libraries
@@ -1680,12 +1694,14 @@ foreach(COMPONENT ${Boost_FIND_COMPONENTS})
   # Avoid passing backslashes to _Boost_FIND_LIBRARY due to macro re-parsing.
   string(REPLACE "\\" "/" _boost_LIBRARY_SEARCH_DIRS_tmp "${_boost_LIBRARY_SEARCH_DIRS_DEBUG}")
 
-  _Boost_FIND_LIBRARY(Boost_${UPPERCOMPONENT}_LIBRARY_DEBUG DEBUG
-    NAMES ${_boost_DEBUG_NAMES}
-    HINTS ${_boost_LIBRARY_SEARCH_DIRS_tmp}
-    NAMES_PER_DIR
-    DOC "${_boost_docstring_debug}"
-    )
+  if(Boost_USE_DEBUG_LIBS)
+    _Boost_FIND_LIBRARY(Boost_${UPPERCOMPONENT}_LIBRARY_DEBUG DEBUG
+      NAMES ${_boost_DEBUG_NAMES}
+      HINTS ${_boost_LIBRARY_SEARCH_DIRS_tmp}
+      NAMES_PER_DIR
+      DOC "${_boost_docstring_debug}"
+      )
+  endif ()
 
   if(Boost_REALPATH)
     _Boost_SWAP_WITH_REALPATH(Boost_${UPPERCOMPONENT}_LIBRARY_RELEASE "${_boost_docstring_release}")

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=6dd0a593d94a386f026f9a83fc7f6c33a9356cc1
commit 6dd0a593d94a386f026f9a83fc7f6c33a9356cc1
Merge: c6f9c6f 1dd2c08
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Wed Sep 6 11:37:30 2017 -0400
Commit:     Brad King <brad.king at kitware.com>
CommitDate: Wed Sep 6 11:37:30 2017 -0400

    Merge branch 'backport-irsl-vs15-future' into irsl-vs15-future

diff --cc Modules/InstallRequiredSystemLibraries.cmake
index bbbc9eb,4e8713a..ac8c20b
--- a/Modules/InstallRequiredSystemLibraries.cmake
+++ b/Modules/InstallRequiredSystemLibraries.cmake
@@@ -517,11 -486,12 +516,12 @@@ if(MSVC
  
    # MSVC 8 was the first version with OpenMP
    # Furthermore, there is no debug version of this
 -  if(CMAKE_INSTALL_OPENMP_LIBRARIES)
 +  if(CMAKE_INSTALL_OPENMP_LIBRARIES AND _IRSL_HAVE_MSVC)
-     if(MSVC_VERSION EQUAL 1911)
-       set(_MSOMP_DLL_VERSION 140)
-       set(_MSOMP_IDE_VERSION 15)
-     elseif(MSVC_VERSION EQUAL 1910)
+     set(_MSOMP_DLL_VERSION "")
+     set(_MSOMP_IDE_VERSION "")
+     if(MSVC_VERSION GREATER_EQUAL 2000)
+       # Version not yet supported.
+     elseif(MSVC_VERSION GREATER_EQUAL 1910)
        set(_MSOMP_DLL_VERSION 140)
        set(_MSOMP_IDE_VERSION 15)
      elseif(MSVC_VERSION EQUAL 1900)

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=1dd2c08b199bb451b73e438d62c1b05f6ccc5bd7
commit 1dd2c08b199bb451b73e438d62c1b05f6ccc5bd7
Author:     Brad King <brad.king at kitware.com>
AuthorDate: Wed Sep 6 11:24:50 2017 -0400
Commit:     Brad King <brad.king at kitware.com>
CommitDate: Wed Sep 6 11:36:47 2017 -0400

    InstallRequiredSystemLibraries: Add support for future VS 2017 toolchains
    
    Assume that all cl 19.xx versions will use the same runtime DLL pattern.
    
    Suggested-by: Tomasz Słodkowicz <slodki at users.noreply.github.com>

diff --git a/Modules/InstallRequiredSystemLibraries.cmake b/Modules/InstallRequiredSystemLibraries.cmake
index 1a4e268..4e8713a 100644
--- a/Modules/InstallRequiredSystemLibraries.cmake
+++ b/Modules/InstallRequiredSystemLibraries.cmake
@@ -175,7 +175,12 @@ if(MSVC)
     endif()
   endif()
 
-  if(MSVC_VERSION EQUAL 1911)
+  set(MSVC_REDIST_NAME "")
+  set(_MSVCRT_DLL_VERSION "")
+  set(_MSVCRT_IDE_VERSION "")
+  if(MSVC_VERSION GREATER_EQUAL 2000)
+    message(WARNING "MSVC ${MSVC_VERSION} not yet supported.")
+  elseif(MSVC_VERSION GREATER_EQUAL 1911)
     set(MSVC_REDIST_NAME VC141)
     set(_MSVCRT_DLL_VERSION 140)
     set(_MSVCRT_IDE_VERSION 15)
@@ -199,10 +204,6 @@ if(MSVC)
     set(MSVC_REDIST_NAME VC100)
     set(_MSVCRT_DLL_VERSION 100)
     set(_MSVCRT_IDE_VERSION 10)
-  else()
-    set(MSVC_REDIST_NAME "")
-    set(_MSVCRT_DLL_VERSION "")
-    set(_MSVCRT_IDE_VERSION "")
   endif()
 
   if(_MSVCRT_DLL_VERSION)
@@ -397,10 +398,11 @@ if(MSVC)
         )
     endif()
 
-    if(MSVC_VERSION EQUAL 1911)
-      set(_MFC_DLL_VERSION 140)
-      set(_MFC_IDE_VERSION 15)
-    elseif(MSVC_VERSION EQUAL 1910)
+    set(_MFC_DLL_VERSION "")
+    set(_MFC_IDE_VERSION "")
+    if(MSVC_VERSION GREATER_EQUAL 2000)
+      # Version not yet supported.
+    elseif(MSVC_VERSION GREATER_EQUAL 1910)
       set(_MFC_DLL_VERSION 140)
       set(_MFC_IDE_VERSION 15)
     elseif(MSVC_VERSION EQUAL 1900)
@@ -415,9 +417,6 @@ if(MSVC)
     elseif(MSVC_VERSION EQUAL 1600)
       set(_MFC_DLL_VERSION 100)
       set(_MFC_IDE_VERSION 10)
-    else()
-      set(_MFC_DLL_VERSION "")
-      set(_MFC_IDE_VERSION "")
     endif()
 
     if(_MFC_DLL_VERSION)
@@ -488,10 +487,11 @@ if(MSVC)
   # MSVC 8 was the first version with OpenMP
   # Furthermore, there is no debug version of this
   if(CMAKE_INSTALL_OPENMP_LIBRARIES)
-    if(MSVC_VERSION EQUAL 1911)
-      set(_MSOMP_DLL_VERSION 140)
-      set(_MSOMP_IDE_VERSION 15)
-    elseif(MSVC_VERSION EQUAL 1910)
+    set(_MSOMP_DLL_VERSION "")
+    set(_MSOMP_IDE_VERSION "")
+    if(MSVC_VERSION GREATER_EQUAL 2000)
+      # Version not yet supported.
+    elseif(MSVC_VERSION GREATER_EQUAL 1910)
       set(_MSOMP_DLL_VERSION 140)
       set(_MSOMP_IDE_VERSION 15)
     elseif(MSVC_VERSION EQUAL 1900)
@@ -512,9 +512,6 @@ if(MSVC)
     elseif(MSVC_VERSION EQUAL 1400)
       set(_MSOMP_DLL_VERSION 80)
       set(_MSOMP_IDE_VERSION 8)
-    else()
-      set(_MSOMP_DLL_VERSION "")
-      set(_MSOMP_IDE_VERSION "")
     endif()
 
     if(_MSOMP_DLL_VERSION)

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=3a4f82e9f2edc9cf30c45019685d26658906e48e
commit 3a4f82e9f2edc9cf30c45019685d26658906e48e
Author:     Ben Morgan <Ben.Morgan at warwick.ac.uk>
AuthorDate: Fri Sep 1 16:25:29 2017 +0100
Commit:     Ben Morgan <Ben.Morgan at warwick.ac.uk>
CommitDate: Fri Sep 1 16:25:29 2017 +0100

    Help: Add notes for topic 'FindEXPAT-importedtargets'

diff --git a/Help/release/dev/FindEXPAT-importedtargets.rst b/Help/release/dev/FindEXPAT-importedtargets.rst
new file mode 100644
index 0000000..ea73551
--- /dev/null
+++ b/Help/release/dev/FindEXPAT-importedtargets.rst
@@ -0,0 +1,4 @@
+FindEXPAT-importedtargets
+-------------------------
+
+* The :module:`FindEXPAT` module now provides imported targets.

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=bfe51369a7f2dd29eb08f24b877fdd01b7534e5c
commit bfe51369a7f2dd29eb08f24b877fdd01b7534e5c
Author:     Ben Morgan <Ben.Morgan at warwick.ac.uk>
AuthorDate: Wed Aug 30 12:18:07 2017 +0100
Commit:     Ben Morgan <Ben.Morgan at warwick.ac.uk>
CommitDate: Fri Sep 1 16:02:57 2017 +0100

    FindEXPAT: Add unit test of target and variables

diff --git a/Tests/CMakeLists.txt b/Tests/CMakeLists.txt
index f0e58ee..73918be 100644
--- a/Tests/CMakeLists.txt
+++ b/Tests/CMakeLists.txt
@@ -1427,6 +1427,10 @@ ${CMake_BINARY_DIR}/bin/cmake -DDIR=dev -P ${CMake_SOURCE_DIR}/Utilities/Release
     add_subdirectory(FindDoxygen)
   endif()
 
+  if(CMake_TEST_FindEXPAT)
+    add_subdirectory(FindEXPAT)
+  endif()
+
   if(CMake_TEST_FindGSL)
     add_subdirectory(FindGSL)
   endif()
diff --git a/Tests/FindEXPAT/CMakeLists.txt b/Tests/FindEXPAT/CMakeLists.txt
new file mode 100644
index 0000000..a74174a
--- /dev/null
+++ b/Tests/FindEXPAT/CMakeLists.txt
@@ -0,0 +1,10 @@
+add_test(NAME FindEXPAT.Test COMMAND
+  ${CMAKE_CTEST_COMMAND} -C $<CONFIGURATION>
+  --build-and-test
+  "${CMake_SOURCE_DIR}/Tests/FindEXPAT/Test"
+  "${CMake_BINARY_DIR}/Tests/FindEXPAT/Test"
+  ${build_generator_args}
+  --build-project TestFindEXPAT
+  --build-options ${build_options}
+  --test-command ${CMAKE_CTEST_COMMAND} -V -C $<CONFIGURATION>
+  )
diff --git a/Tests/FindEXPAT/Test/CMakeLists.txt b/Tests/FindEXPAT/Test/CMakeLists.txt
new file mode 100644
index 0000000..5681f74
--- /dev/null
+++ b/Tests/FindEXPAT/Test/CMakeLists.txt
@@ -0,0 +1,16 @@
+cmake_minimum_required(VERSION 3.9)
+project(TestFindEXPAT C)
+include(CTest)
+
+find_package(EXPAT REQUIRED)
+
+add_definitions(-DCMAKE_EXPECTED_EXPAT_VERSION="${EXPAT_VERSION_STRING}")
+
+add_executable(testexpat_tgt main.c)
+target_link_libraries(testexpat_tgt EXPAT::EXPAT)
+add_test(NAME testexpat_tgt COMMAND testexpat_tgt)
+
+add_executable(testexpat_var main.c)
+target_include_directories(testexpat_var PRIVATE ${EXPAT_INCLUDE_DIRS})
+target_link_libraries(testexpat_var PRIVATE ${EXPAT_LIBRARIES})
+add_test(NAME testexpat_var COMMAND testexpat_var)
diff --git a/Tests/FindEXPAT/Test/main.c b/Tests/FindEXPAT/Test/main.c
new file mode 100644
index 0000000..94ee3ef
--- /dev/null
+++ b/Tests/FindEXPAT/Test/main.c
@@ -0,0 +1,21 @@
+#include <expat.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
+int main()
+{
+  XML_Expat_Version expat_version;
+  char expat_version_string[16];
+
+  expat_version = XML_ExpatVersionInfo();
+
+  snprintf(expat_version_string, 16, "%i.%i.%i", expat_version.major,
+           expat_version.minor, expat_version.micro);
+
+  if (strcmp(expat_version_string, CMAKE_EXPECTED_EXPAT_VERSION) != 0) {
+    return EXIT_FAILURE;
+  }
+
+  return EXIT_SUCCESS;
+}

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=78f166f8730c4da4ad21ba6218803f1a6552a95a
commit 78f166f8730c4da4ad21ba6218803f1a6552a95a
Author:     Ben Morgan <Ben.Morgan at warwick.ac.uk>
AuthorDate: Tue Aug 29 18:24:08 2017 +0100
Commit:     Ben Morgan <Ben.Morgan at warwick.ac.uk>
CommitDate: Fri Sep 1 16:02:46 2017 +0100

    FindEXPAT: Add imported target and documentation

diff --git a/Modules/FindEXPAT.cmake b/Modules/FindEXPAT.cmake
index 09963fc..39086e4 100644
--- a/Modules/FindEXPAT.cmake
+++ b/Modules/FindEXPAT.cmake
@@ -5,15 +5,28 @@
 # FindEXPAT
 # ---------
 #
-# Find expat
+# Find the native Expat headers and library.
 #
-# Find the native EXPAT headers and libraries.
+# Imported Targets
+# ^^^^^^^^^^^^^^^^
 #
-# ::
+# This module defines the following :prop_tgt:`IMPORTED` targets:
+#
+# ``EXPAT::EXPAT``
+#   The Expat ``expat`` library, if found.
+#
+# Result Variables
+# ^^^^^^^^^^^^^^^^
+#
+# This module will set the following variables in your project:
+#
+# ``EXPAT_INCLUDE_DIRS``
+#   where to find expat.h, etc.
+# ``EXPAT_LIBRARIES``
+#   the libraries to link against to use Expat.
+# ``EXPAT_FOUND``
+#   true if the Expat headers and libraries were found.
 #
-#   EXPAT_INCLUDE_DIRS - where to find expat.h, etc.
-#   EXPAT_LIBRARIES    - List of libraries when using expat.
-#   EXPAT_FOUND        - True if expat found.
 
 find_package(PkgConfig QUIET)
 
@@ -49,10 +62,18 @@ FIND_PACKAGE_HANDLE_STANDARD_ARGS(EXPAT
                                   REQUIRED_VARS EXPAT_LIBRARY EXPAT_INCLUDE_DIR
                                   VERSION_VAR EXPAT_VERSION_STRING)
 
 # Copy the results to the output variables.
 if(EXPAT_FOUND)
   set(EXPAT_LIBRARIES ${EXPAT_LIBRARY})
   set(EXPAT_INCLUDE_DIRS ${EXPAT_INCLUDE_DIR})
+
+  if(NOT TARGET EXPAT::EXPAT)
+    add_library(EXPAT::EXPAT UNKNOWN IMPORTED)
+    set_target_properties(EXPAT::EXPAT PROPERTIES
+      IMPORTED_LINK_INTERFACE_LANGUAGES "C"
+      IMPORTED_LOCATION "${EXPAT_LIBRARY}"
+      INTERFACE_INCLUDE_DIRECTORIES "${EXPAT_INCLUDE_DIRS}")
+  endif()
 endif()
 
 mark_as_advanced(EXPAT_INCLUDE_DIR EXPAT_LIBRARY)

-----------------------------------------------------------------------

Summary of changes:
 Help/release/dev/FindEXPAT-importedtargets.rst |    4 ++
@@ -49,10 +62,18 @@ FIND_PACKAGE_HANDLE_STANDARD_ARGS(EXPAT
                                   VERSION_VAR EXPAT_VERSION_STRING)
 
-# Copy the results to the output variables.
+# Copy the results to the output variables and target.
 if(EXPAT_FOUND)
   set(EXPAT_LIBRARIES ${EXPAT_LIBRARY})
 Modules/FindBoost.cmake                        |   48 ++++++++++++++++--------
 Modules/FindEXPAT.cmake                        |   35 +++++++++++++----
 Modules/InstallRequiredSystemLibraries.cmake   |   35 ++++++++---------
 Tests/CMakeLists.txt                           |    4 ++
 Tests/{FindLibUV => FindEXPAT}/CMakeLists.txt  |    8 ++--
 Tests/FindEXPAT/Test/CMakeLists.txt            |   16 ++++++++
 Tests/FindEXPAT/Test/main.c                    |   21 +++++++++++
 8 files changed, 125 insertions(+), 46 deletions(-)
 create mode 100644 Help/release/dev/FindEXPAT-importedtargets.rst
 copy Tests/{FindLibUV => FindEXPAT}/CMakeLists.txt (54%)
 create mode 100644 Tests/FindEXPAT/Test/CMakeLists.txt
 create mode 100644 Tests/FindEXPAT/Test/main.c


hooks/post-receive
-- 
CMake


More information about the Cmake-commits mailing list